@@ -48,7 +48,4 @@
 //! ### Resources
 //! - [Automatic Differentation in Rust](https://github.com/JonathanWoollett-Light/autodiff-book)
 //! - [automatic-differentiation-worked-examples](http://h2.jaguarpaw.co.uk/posts/automatic-differentiation-worked-examples/)
-pub use rust_ad_macros::*;
-
-#[cfg(test)]
-mod tests;
+pub use rust_ad_macros::*;
\ No newline at end of file
